@@ -3,7 +3,7 @@ package Makefile::AST;
 use strict;
 use warnings;
 
-our $VERSION = '0.214';
+our $VERSION = '0.216';
 
 #use Smart::Comments;
 #use Smart::Comments '####';
@@ -363,13 +363,18 @@ sub eval_var_value ($$) {
         if ($var->flavor eq 'recursive') {
             ## HERE! eval_var_value
             ## eval recursive var: $var
-            return $self->solve_refs_in_tokens(
+            my $val =  $self->solve_refs_in_tokens(
                 $var->value
             );
+            $val =~ s/^\s+|\s+$//gs;
+            #warn "value: $val\n";
+            return $val;
         } else {
             # don't complain about uninitialized value:
             no warnings 'uninitialized';
-            return join '', @{$var->value};
+            my $val = join '', @{$var->value};
+            $val =~ s/^\s+|\s+$//gs;
+            return $val;
         }
     } else {
         # process undefined var:
@@ -819,7 +824,7 @@ Used to encapsulate information regarding makefile rule commands (e.g. command b
 
 =head1 LIMITATIONS AND TODO
 
-Adding support for other flavors' makes into this AST libary should make a huge amount of sense. The most interesting candiate is Microsoft's NMAKE.
+Adding support for other flavors' makes into this AST library should make a huge amount of sense. The most interesting candiate is Microsoft's NMAKE.
 
 =head1 CODE REPOSITORY
 
