@@ -10,7 +10,7 @@ use List::MoreUtils qw( none );
 use MDOM::Document::Gmake;
 use Makefile::AST;
 
-our $VERSION = '0.214';
+our $VERSION = '0.216';
 
 # XXX This should not be hard-coded this way...
 our @Suffixes = (
@@ -338,15 +338,25 @@ sub parse ($$) {
             if ($elem->name eq 'endef') {
                 ### parsed a define directive: $directive
                 # trim the trailing new lines in the value:
-                my $last = $directive->{value}->[-1]->last_element;
-                #warn "LAST: '$last'\n";
-                if ($last and $last eq "\n") {
-                    $directive->{value}->[-1]->remove_child($last);
+                #warn "HERE!!! ";
+                #warn quotemeta($directive->{value}->[-1]);
+                my $last = $directive->{value}->[-1];
+                if ("$last" =~ /^\s*$/s) {
+                    pop @{ $directive->{value} }
+
+                } elsif ($last->can('last_element')) {
+                    my $last_elem = $last->last_element;
+                    #warn "LAST: '$last'\n";
+                    if ($last_elem and "$last_elem" =~ /^\s*$/s) {
+                        $last->remove_child($last_elem);
+                    }
                 }
+
                 my $var = Makefile::AST::Variable->new($directive);
                 $ast->add_var($var);
                 undef $var_origin;
                 undef $directive;
+
             } else {
                 warn "warning: line " . $elem->lineno .
                     ": Unknown directive: " . $elem->source;
@@ -391,7 +401,7 @@ Makefile::Parser::GmakeDB - GNU makefile parser using GNU make's database dump
 
 =head1 VERSION
 
-This document describes Makefile::Parser::GmakeDB 0.214 released on 17 August 2011.
+This document describes Makefile::Parser::GmakeDB 0.216 released on 18 November 2014.
 
 =head1 SYNOPSIS
 
